@@ -4,6 +4,10 @@ import json
 from payout.create_payout_account import CreatePayoutAccount
 from payout.update_payout_account import UpdatePayoutAccount
 from payout.find_payout_account import FindPayoutAccount
+from payout.add_payout_token import AddPayoutToken
+from payout.add_payout_rate import AddPayoutRate
+from payout.start_payouts import StartPayouts
+from payout.stop_payouts import StopPayouts
 
 
 class Payout:
@@ -21,13 +25,11 @@ class Payout:
             self.dataEndpoints = response["dataEndpoints"]
         else:
             self.dataEndpoints = "ERROR Unable to get dataEndpoints from server"
-        # print("dataEndpoints -> " + self.dataEndpoints)
         # Parse and set redpayEndpoints
         if "redpayEndpoints" in response:
             self.redpayEndpoints = response["redpayEndpoints"]
         else:
             self.redpayEndpoints = "ERROR Unable to get redpayEndpoints from server"
-        # print("redpayEndpoints -> " + self.redpayEndpoints)
 
     def CreatePayoutAccount(self, request):
         request["app"] = self.app
@@ -47,8 +49,30 @@ class Payout:
             self.app, self.key, self.dataEndpoints)
         return find_payout_account.Process(request)
 
-    def AddPaymentRate(self, request):
-        pass
+    def AddPayoutRate(self, request):
+        request["app"] = self.app
+        request["account"] = request["id"]
+        add_payout_rate = AddPayoutRate(
+            self.app, self.key, self.dataEndpoints)
+        return add_payout_rate.Process(request)
 
-    def AddPaymentToken(self, request):
-        pass
+    def AddPayoutToken(self, request):
+        request["app"] = self.app
+        request["account"] = request["id"]
+        add_payout_token = AddPayoutToken(
+            self.app, self.key, self.dataEndpoints)
+        return add_payout_token.Process(request)
+
+    def StartPayouts(self, request):
+        request["app"] = self.app
+        request["account"] = request["id"]
+        start_payouts = StartPayouts(
+            self.app, self.key, self.dataEndpoints)
+        return start_payouts.Process(request)
+
+    def StopPayouts(self, request):
+        request["app"] = self.app
+        request["account"] = request["id"]
+        stop_payouts = StopPayouts(
+            self.app, self.key, self.dataEndpoints)
+        return stop_payouts.Process(request)
